// This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
// International Public License.
// Visit https://creativecommons.org/licenses/by-sa/4.0/.
// SPDX-License-Identifier: CC-BY-SA-4.0
//     yuqk f_interior_fade.pov +w800 +h600 +a0.05 +am2 +r3
#version unofficial 3.8; // yuqk
#if (file_exists("version.inc"))
    #include "version.inc"
#end
#if (!defined(Fork_yuqk))
    #error "This POV-Ray SDL code requires the yuqk fork."
#end
global_settings { assumed_gamma 1 }
default {
    finish { diffuse 0.0 emission 1.0 }
}
#declare BrownCrayola = srgb <0.68627,0.34902,0.24314>;
background { BrownCrayola }
#declare VarOrthoMult =
    4.1/max(image_width/image_height,image_height/image_width);
#declare Camera01z = camera {
    orthographic
    location <1,0,-2>
    direction z
    right VarOrthoMult*x*max(1,image_width/image_height)
    up VarOrthoMult*y*max(1,image_height/image_width)
}
#declare Red = srgb <1,0,0>;
#declare CylinderX = cylinder { -1*x, 1*x, 0.01 pigment { Red } }
#declare Green = srgb <0,1,0>;
#declare CylinderY = cylinder { -1*y, 1*y, 0.01 pigment { Green } }
#declare Blue = srgb <0,0,1>;
#declare CylinderZ = cylinder { -1*z, 1*z, 0.01 pigment { Blue } }
#declare Yellow = srgb <1,1,0>;
#declare CylinderZY = cylinder {
    -1*z, 1*z, 0.01
    pigment { Yellow }
}
#declare Black = srgb <0,0,0>;
#declare CylinderZD = cylinder { -1*z, 1*z, 0.01 pigment { Black } }
#declare Cyan = srgb <0,1,1>;

// With the inbuilt function, f_interior_fade(), trying to give users access to a
// commonly used function inside the interior fade feature. A general idea pushed
// by Bald Eagle and others on the newsgroups has been to make available internal
// calculations in a way the user can grab themselves to understand. Creating
// inbuilt functions which parallel internal functions is a way of doing it. Here
// an example scene which plots the function using a couple isosurfaces.
#declare Amplify = +1.0;
#declare FadeColr = +0.0;
#declare FadeDist = +0.5;
#declare FadePow = +2.72;
#declare iMax = +1.0;
#include "functions.inc"
// Function f_planar defined in functions.inc
// Function f_interior_fade defined in functions.inc
#declare Fn_pow = function (x,y,z) {
    f_planar(y-f_interior_fade(Amplify,max(1e-6,x),FadeColr,FadeDist,FadePow,iMax),0.01,1)
}
#declare Fn_exp = function (x,y,z) {
    f_planar(y-f_interior_fade(Amplify,max(1e-6,x),FadeColr,FadeDist,1000.00,iMax),0.01,1)
}
#declare Iso_pow = isosurface {
    function { Fn_pow(x,y,z) }
    contained_by { box { <-2,-2,-0>,<3,2,0.1> } }
    threshold 0
    accuracy 0.0005
    max_gradient 1.1
    pigment { Cyan }
}
#declare CyanCornflowerBlue = srgb <0.09412,0.5451,0.76078>;
#declare Iso_exp = isosurface {
    function { Fn_exp(x,y,z) }
    contained_by { box { <-2,-2,-0>,<3,2,0.1> } }
    threshold 0
    accuracy 0.0005
    max_gradient 1.1
    pigment { CyanCornflowerBlue }
}
#declare CapStr = concat("Pow vs Exp  Amp ",str(Amplify,4,2),
    "  FaToCol ",str(FadeColr,4,2),
    "  FaDist ",str(FadeDist,4,2),
    "  FaPow ",str(FadePow,4,2),"/1000.0",
    "  iMax ",str(iMax,4,2))
#declare White = srgb <1,1,1>;
#declare Text00 = text {
    ttf "timrom.ttf" CapStr
    0.1, 0
    pigment { White }
    scale 0.09
    translate <-0.5,-1.4,0>
}
#declare Obj00 = object {
    CylinderZ
    rotate x*90
    scale <1,0.5,1>
    translate <-0.5,0,0>
}
#declare Obj01 = object {
    CylinderZ
    rotate x*90
    scale <1,0.5,1>
    translate <+0.5,0,0>
}
#declare Obj02 = object {
    CylinderZY
    rotate x*90
    translate <+2.0,0,0>
}
#declare Obj03 = object {
    CylinderZY
    rotate x*90
    translate <+3.0,0,0>
}
#declare Obj04 = object {
    CylinderZD
    rotate x*90
    translate <FadeDist,0,0.001>
}
#declare U00 = union {
    object { Obj00 }
    object { Obj01 }
    object { Obj02 }
    object { Obj03 }
    object { Obj04 }
    object { CylinderX }
    object { CylinderY }
    object { CylinderZ }
}

//--- scene ---
    camera { Camera01z }
    object { Iso_pow }
    object { Iso_exp }
    object { U00 }
    object { Text00 }
